@@ -510,8 +510,15 @@ gcc_optimization_opts = [
 ]
 
 cif_supported_opts = (
-    ["-D", "-U", "-nostdinc", "-fshort-wchar", "-std", "--std", "-c"]
-    + ["-mbig-endian", "-mlittle-endian", "-mabi"]  # arm
+    ["-D", "-U", "-std", "--std", "-c", ]
+    # Relation to a host environment such as the standard library. This is especially important for OS kernels.
+    + ["-nostdinc", "-fno-builtin", "-fno-hosted", "-ffreestanding"]
+    # Options controlling types representation.
+    + ["-fshort-wchar", "-fno-short-wchar", "-fshort-enums", "-fno-short-enums"]
+    # Machine-dependent options.
+    + ["-mbig-endian", "-mlittle-endian", "-mabi"]
+    # Options to enable different kinds of errors. They can help to make the source code better.
+    + ["-Werror-implicit-function-declaration", "-Werror=implicit-function-declaration"]
     + ["{}$".format(opt) for opt in gcc_optimization_opts]
     + include_opts
 )
